pub enum EncryptError {
InvalidKey,
EncryptionFailed,
DecryptionFailed,
InvalidPayload,
Base64Error(String),
Utf8Error(String),
}Expand description
Encryption errors. 加密错误。
Variants
InvalidKey
Invalid encryption key. / 无效加密密钥。
EncryptionFailed
Encryption operation failed. / 加密操作失败。
DecryptionFailed
Decryption failed due to wrong password or corrupted data. / 解密失败,密码错误或数据损坏。
InvalidPayload
Payload is too short to contain nonce and ciphertext. / 载荷过短,无法包含 nonce 和密文。
Base64Error(String)
Base64 encoding/decoding error. / Base64 编解码错误。
Utf8Error(String)
UTF-8 encoding error. / UTF-8 编码错误。